Module bridge

Module bridge 

Runtime-loaded bridge access for cbf_bridge.

Structs

ArcLibloadingError
A cloneable wrapper around libloading::Error.
BridgeLibrary
A process-wide loaded bridge API wrapper.
BridgeLoadOptions
Options for overriding how the bridge library is located at runtime.

Enums

BridgeLoadError
Errors that can occur while locating or opening the bridge library.

Functions

bridge
Return the process-wide bridge API instance, loading it on first use.
resolve_bridge_library_path
Resolve the bridge library path from explicit options and known runtime locations.