pub enum BridgeLoadError {
PathNotFound,
LoadLibrary {
path: PathBuf,
source: ArcLibloadingError,
},
}Expand description
Errors that can occur while locating or opening the bridge library.
Variants
PathNotFound
No supported runtime search location contained the bridge library.
LoadLibrary
Loading the discovered bridge library file or one of its required symbols failed.
Fields

source: ArcLibloadingErrorThe underlying dynamic loader error.