pub struct BridgeLibrary { /* private fields */ }Expand description
A process-wide loaded bridge API wrapper.
Implementations
Sourceimpl BridgeLibrary
impl BridgeLibrary
Sourcepub fn load(options: &BridgeLoadOptions) -> Result<Self, BridgeLoadError>
pub fn load(options: &BridgeLoadOptions) -> Result<Self, BridgeLoadError>
Load the bridge API using the provided search options.
The library file path is resolved by resolve_bridge_library_path.
See that function for the runtime search order and fallback behavior.
Sourcepub fn library_path(&self) -> &Path
pub fn library_path(&self) -> &Path
Return the resolved filesystem path of the loaded bridge library.
Methods from Deref<Target = CbfBridge>
pub unsafe fn cbf_bridge_convert_nsevent( &self, nsevent: *mut c_void, tab_id: u64, out_event: *mut CbfKeyEvent, )
pub unsafe fn cbf_bridge_free_converted_key_event( &self, event: *mut CbfKeyEvent, )
pub unsafe fn cbf_bridge_convert_nsevent_to_mouse_event( &self, nsevent: *mut c_void, nsview: *mut c_void, tab_id: u64, pointer_type: u8, unaccelerated_movement: bool, out_event: *mut CbfMouseEvent, )
pub unsafe fn cbf_bridge_convert_nsevent_to_mouse_wheel_event( &self, nsevent: *mut c_void, nsview: *mut c_void, tab_id: u64, out_event: *mut CbfMouseWheelEvent, )
pub unsafe fn cbf_bridge_convert_nspasteboard_to_drag_data( &self, nspasteboard: *mut c_void, out_data: *mut CbfDragData, )
pub unsafe fn cbf_bridge_free_converted_drag_data(&self, data: *mut CbfDragData)
pub unsafe fn cbf_bridge_client_wait_for_event( &self, client: *mut CbfBridgeClientHandle, timeout_ms: i64, ) -> CbfBridgeEventWaitStatus
pub unsafe fn cbf_bridge_client_send_external_drag_enter( &self, client: *mut CbfBridgeClientHandle, event: *const CbfExternalDragEnter, ) -> bool
pub unsafe fn cbf_bridge_client_send_external_drag_update( &self, client: *mut CbfBridgeClientHandle, event: *const CbfExternalDragUpdate, ) -> bool
pub unsafe fn cbf_bridge_client_send_external_drag_leave( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_send_external_drag_drop( &self, client: *mut CbfBridgeClientHandle, event: *const CbfExternalDragDrop, ) -> bool
pub unsafe fn cbf_bridge_client_execute_edit_action( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, action: u8, ) -> bool
pub unsafe fn cbf_bridge_client_find_in_page( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, request_id: u64, query: *const c_char, forward: bool, match_case: bool, new_session: bool, find_match: bool, ) -> bool
pub unsafe fn cbf_bridge_client_stop_finding( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, action: u8, ) -> bool
pub unsafe fn cbf_bridge_client_execute_extension_popup_edit_action( &self, client: *mut CbfBridgeClientHandle, popup_id: u64, action: u8, ) -> bool
pub unsafe fn cbf_bridge_client_confirm_beforeunload( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, request_id: u64, proceed: bool, ) -> bool
pub unsafe fn cbf_bridge_client_respond_javascript_dialog( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, request_id: u64, accept: bool, prompt_text: *const c_char, ) -> bool
pub unsafe fn cbf_bridge_client_respond_extension_popup_javascript_dialog( &self, client: *mut CbfBridgeClientHandle, popup_id: u64, request_id: u64, accept: bool, prompt_text: *const c_char, ) -> bool
pub unsafe fn cbf_bridge_client_go_back( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_go_forward( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_reload( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, ignore_cache: bool, ) -> bool
pub unsafe fn cbf_bridge_client_print_preview( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_activate_extension_action( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, extension_id: *const c_char, ) -> bool
pub unsafe fn cbf_bridge_client_open_dev_tools( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_inspect_element( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, x: i32, y: i32, ) -> bool
pub unsafe fn cbf_bridge_client_set_tab_focus( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, focused: bool, ) -> bool
pub unsafe fn cbf_bridge_client_set_tab_visibility( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, visibility: u8, ) -> bool
pub unsafe fn cbf_bridge_client_set_tab_execution_state( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, state: u8, ) -> bool
pub unsafe fn cbf_bridge_client_enable_tab_ipc( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, allowed_origins: *const CbfCommandList, ) -> bool
pub unsafe fn cbf_bridge_client_disable_tab_ipc( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_post_tab_ipc_message( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, channel: *const c_char, message_type: u8, request_id: u64, payload_kind: u8, payload_text: *const c_char, payload_binary: *const u8, payload_binary_len: u32, content_type: *const c_char, error_code: u8, ) -> bool
pub unsafe fn cbf_bridge_client_set_tab_background_policy( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, transparent: bool, ) -> bool
pub unsafe fn cbf_bridge_client_set_extension_popup_background_policy( &self, client: *mut CbfBridgeClientHandle, popup_id: u64, transparent: bool, ) -> bool
pub unsafe fn cbf_bridge_client_get_tab_dom_html( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, request_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_traverse_history_to_entry( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, entry_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_traverse_history_by_offset( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, delta: i32, ) -> bool
pub unsafe fn cbf_bridge_client_list_extensions( &self, client: *mut CbfBridgeClientHandle, profile_id: *const c_char, out_list: *mut CbfExtensionInfoList, ) -> bool
pub unsafe fn cbf_bridge_extension_list_free( &self, list: *mut CbfExtensionInfoList, )
pub unsafe fn cbf_bridge_client_open_default_prompt_ui( &self, client: *mut CbfBridgeClientHandle, profile_id: *const c_char, request_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_register_custom_scheme_handler( &self, client: *mut CbfBridgeClientHandle, scheme: *const c_char, host: *const c_char, ) -> bool
pub unsafe fn cbf_bridge_client_respond_custom_scheme_request( &self, client: *mut CbfBridgeClientHandle, request_id: u64, result: u8, mime_type: *const c_char, content_security_policy: *const c_char, access_control_allow_origin: *const c_char, body: *const u8, body_len: u32, ) -> bool
pub unsafe fn cbf_bridge_client_respond_prompt_ui( &self, client: *mut CbfBridgeClientHandle, profile_id: *const c_char, request_id: u64, prompt_ui_kind: u8, proceed: bool, report_abuse: bool, destination_path: *const c_char, ) -> bool
pub unsafe fn cbf_bridge_client_respond_prompt_ui_for_tab( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, request_id: u64, prompt_ui_kind: u8, proceed: bool, report_abuse: bool, destination_path: *const c_char, ) -> bool
pub unsafe fn cbf_bridge_client_pause_download( &self, client: *mut CbfBridgeClientHandle, download_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_resume_download( &self, client: *mut CbfBridgeClientHandle, download_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_cancel_download( &self, client: *mut CbfBridgeClientHandle, download_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_close_prompt_ui( &self, client: *mut CbfBridgeClientHandle, profile_id: *const c_char, prompt_ui_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_respond_tab_open( &self, client: *mut CbfBridgeClientHandle, request_id: u64, response_kind: u8, target_tab_id: u64, activate: bool, ) -> bool
pub unsafe fn cbf_bridge_set_base_bundle_id(&self, bundle_id: *const c_char)
pub unsafe fn cbf_bridge_client_create(&self) -> *mut CbfBridgeClientHandle
pub unsafe fn cbf_bridge_client_destroy( &self, client: *mut CbfBridgeClientHandle, )
pub unsafe fn cbf_bridge_init(&self)
pub unsafe fn cbf_bridge_prepare_channel( &self, out_switch_arg: *mut c_char, out_arg_len: c_int, ) -> c_int
pub unsafe fn cbf_bridge_prepare_channel_and_lock( &self, out_switch_arg: *mut c_char, out_arg_len: c_int, ) -> c_int
pub unsafe fn cbf_bridge_pass_child_pid(&self, child_pid: i64)
pub unsafe fn cbf_bridge_pass_child_pid_and_unlock(&self, child_pid: i64)
pub unsafe fn cbf_bridge_abort_channel_launch(&self)
pub unsafe fn cbf_bridge_client_connect_inherited( &self, client: *mut CbfBridgeClientHandle, ) -> bool
pub unsafe fn cbf_bridge_client_authenticate( &self, client: *mut CbfBridgeClientHandle, token: *const c_char, ) -> bool
pub unsafe fn cbf_bridge_client_poll_event( &self, client: *mut CbfBridgeClientHandle, out_event: *mut CbfBridgeEvent, ) -> bool
pub unsafe fn cbf_bridge_event_free(&self, event: *mut CbfBridgeEvent)
pub unsafe fn cbf_bridge_client_get_profiles( &self, client: *mut CbfBridgeClientHandle, out_list: *mut CbfProfileList, ) -> bool
pub unsafe fn cbf_bridge_profile_list_free(&self, list: *mut CbfProfileList)
pub unsafe fn cbf_bridge_client_create_tab( &self, client: *mut CbfBridgeClientHandle, request_id: u64, initial_url: *const c_char, profile_id: *const c_char, has_policy: bool, ipc_policy_kind: u8, allowed_origins: *const CbfCommandList, extensions_policy: u8, ) -> bool
pub unsafe fn cbf_bridge_client_request_close_tab( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_begin_close_tabs_transaction( &self, client: *mut CbfBridgeClientHandle, request_id: u64, tab_ids: *const CbfUint64List, ) -> bool
pub unsafe fn cbf_bridge_client_commit_close_tabs_transaction( &self, client: *mut CbfBridgeClientHandle, request_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_cancel_close_tabs_transaction( &self, client: *mut CbfBridgeClientHandle, request_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_set_tab_size( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, width: u32, height: u32, ) -> bool
pub unsafe fn cbf_bridge_client_send_key_event( &self, client: *mut CbfBridgeClientHandle, event: *const CbfKeyEvent, commands: *const CbfCommandList, ) -> bool
pub unsafe fn cbf_bridge_client_send_mouse_event( &self, client: *mut CbfBridgeClientHandle, event: *const CbfMouseEvent, ) -> bool
pub unsafe fn cbf_bridge_client_send_mouse_wheel_event( &self, client: *mut CbfBridgeClientHandle, event: *const CbfMouseWheelEvent, ) -> bool
pub unsafe fn cbf_bridge_client_send_drag_update( &self, client: *mut CbfBridgeClientHandle, update: *const CbfDragUpdate, ) -> bool
pub unsafe fn cbf_bridge_client_send_drag_drop( &self, client: *mut CbfBridgeClientHandle, drop: *const CbfDragDrop, ) -> bool
pub unsafe fn cbf_bridge_client_send_drag_cancel( &self, client: *mut CbfBridgeClientHandle, session_id: u64, tab_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_set_composition( &self, client: *mut CbfBridgeClientHandle, composition: *const CbfImeComposition, ) -> bool
pub unsafe fn cbf_bridge_client_commit_text( &self, client: *mut CbfBridgeClientHandle, commit: *const CbfImeCommitText, ) -> bool
pub unsafe fn cbf_bridge_client_finish_composing_text( &self, client: *mut CbfBridgeClientHandle, tab_id: u64, behavior: u8, ) -> bool
pub unsafe fn cbf_bridge_client_set_extension_popup_size( &self, client: *mut CbfBridgeClientHandle, popup_id: u64, width: u32, height: u32, ) -> bool
pub unsafe fn cbf_bridge_client_set_extension_popup_focus( &self, client: *mut CbfBridgeClientHandle, popup_id: u64, focused: bool, ) -> bool
pub unsafe fn cbf_bridge_client_send_extension_popup_key_event( &self, client: *mut CbfBridgeClientHandle, popup_id: u64, event: *const CbfKeyEvent, commands: *const CbfCommandList, ) -> bool
pub unsafe fn cbf_bridge_client_send_extension_popup_mouse_event( &self, client: *mut CbfBridgeClientHandle, popup_id: u64, event: *const CbfMouseEvent, ) -> bool
pub unsafe fn cbf_bridge_client_send_extension_popup_mouse_wheel_event( &self, client: *mut CbfBridgeClientHandle, popup_id: u64, event: *const CbfMouseWheelEvent, ) -> bool
pub unsafe fn cbf_bridge_client_set_extension_popup_composition( &self, client: *mut CbfBridgeClientHandle, popup_id: u64, composition: *const CbfImeComposition, ) -> bool
pub unsafe fn cbf_bridge_client_commit_extension_popup_text( &self, client: *mut CbfBridgeClientHandle, popup_id: u64, commit: *const CbfImeCommitText, ) -> bool
pub unsafe fn cbf_bridge_client_finish_extension_popup_composing_text( &self, client: *mut CbfBridgeClientHandle, popup_id: u64, behavior: u8, ) -> bool
pub unsafe fn cbf_bridge_client_close_extension_popup( &self, client: *mut CbfBridgeClientHandle, popup_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_shutdown( &self, client: *mut CbfBridgeClientHandle, )
pub unsafe fn cbf_bridge_client_request_shutdown( &self, client: *mut CbfBridgeClientHandle, request_id: u64, ) -> bool
pub unsafe fn cbf_bridge_client_confirm_shutdown( &self, client: *mut CbfBridgeClientHandle, request_id: u64, proceed: bool, ) -> bool
pub unsafe fn cbf_bridge_client_force_shutdown( &self, client: *mut CbfBridgeClientHandle, ) -> bool