pub struct BridgeLoadOptions {
pub explicit_library_path: Option<PathBuf>,
pub explicit_library_dir: Option<PathBuf>,
}Expand description
Options for overriding how the bridge library is located at runtime.
Fields
explicit_library_path: Option<PathBuf>An explicit full path to the bridge library file.
explicit_library_dir: Option<PathBuf>An explicit directory that contains the bridge library file.
Implementations
Sourceimpl BridgeLoadOptions
impl BridgeLoadOptions
Sourcepub fn with_explicit_library_path(self, path: impl Into<PathBuf>) -> Self
pub fn with_explicit_library_path(self, path: impl Into<PathBuf>) -> Self
Return options that load the bridge from an explicit file path.
Sourcepub fn with_explicit_library_dir(self, path: impl Into<PathBuf>) -> Self
pub fn with_explicit_library_dir(self, path: impl Into<PathBuf>) -> Self
Return options that load the bridge from an explicit directory.