Runtime-loaded bridge access for cbf_bridge.
Structs
- ArcLibloading
Error - A cloneable wrapper around
libloading::Error. - Bridge
Library - A process-wide loaded bridge API wrapper.
- Bridge
Load Options - Options for overriding how the bridge library is located at runtime.
Enums
- Bridge
Load Error - Errors that can occur while locating or opening the bridge library.
Functions
- bridge
- Return the process-wide bridge API instance, loading it on first use.
- resolve_
bridge_ library_ path - Resolve the bridge library path from explicit options and known runtime locations.